@@ -1,4 +1,5 @@
 import io
+from typing import List
 
 import fitz
 from PIL import Image
@@ -10,7 +11,7 @@ def pdf_to_image(
         format: str = 'jpeg',
         dpi: int = 220,
         limit: int = None,
-):
+) -> List[bytes]:
     result = []
     pdf = fitz.Document(stream=io.BytesIO(source), filetype='pdf')
     for i, page in enumerate(pdf):
